@@ -56,6 +56,7 @@ AddMagickCoder(DPX)
 #if defined(MAGICKCORE_OPENEXR_DELEGATE)
   AddMagickCoder(EXR)
 #endif
+AddMagickCoder(FARBFELD)
 AddMagickCoder(FAX)
 AddMagickCoder(FITS)
 AddMagickCoder(FL32)
@@ -188,5 +189,6 @@ AddMagickCoder(XTRN)
 #if defined(MAGICKCORE_X11_DELEGATE)
   AddMagickCoder(XWD)
 #endif
+AddMagickCoder(YAML)
 AddMagickCoder(YCBCR)
 AddMagickCoder(YUV)
