@@ -1131,8 +1131,8 @@ static MagickBooleanType WriteDIBImage(const ImageInfo *image_info,Image *image,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,exception);
   if (status == MagickFalse)
     return(status);
-  if (((image->columns << 3) != (int) (image->columns << 3)) ||
-      ((image->rows << 3) != (int) (image->rows << 3)))
+  if (((image->columns << 3) != (size_t) ((int) (image->columns << 3))) ||
+      ((image->rows << 3) != (size_t) ((int) (image->rows << 3))))
     ThrowWriterException(ImageError,"WidthOrHeightExceedsLimit");
   /*
     Initialize DIB raster file header.
