@@ -116,7 +116,8 @@ static MagickBooleanType IsPNM(const unsigned char *magick,const size_t extent)
   if ((*magick == (unsigned char) 'P') &&
       ((magick[1] == '1') || (magick[1] == '2') || (magick[1] == '3') ||
        (magick[1] == '4') || (magick[1] == '5') || (magick[1] == '6') ||
-       (magick[1] == '7') || (magick[1] == 'F') || (magick[1] == 'f')))
+       (magick[1] == '7') || (magick[1] == 'F') || (magick[1] == 'f') ||
+       (magick[1] == 'H') || (magick[1] == 'h')))
     return(MagickTrue);
   return(MagickFalse);
 }
@@ -227,6 +228,31 @@ static unsigned int PNMInteger(Image *image,CommentInfo *comment_info,
   return(value);
 }
 
+static char *PNMString(Image *image,char *string,const size_t extent)
+{
+  int
+    c;
+
+  register size_t
+    i;
+
+  for (i=0; i < (extent-1L); i++)
+  {
+    c=ReadBlobByte(image);
+    if (c == EOF)
+      {
+        if (i == 0)
+          return((char *) NULL);
+        break;
+      }
+    string[i]=c;
+    if (c == '\n' || c == '\r')
+      break;
+  }
+  string[i]='\0';
+  return(string);
+}
+
 static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define ThrowPNMException(exception,message) \
@@ -315,14 +341,17 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           PBM, PGM, PPM, and PNM.
         */
+        if (ReadBlobByte(image) == '4')
+          image->alpha_trait=BlendPixelTrait;
         image->columns=(size_t) PNMInteger(image,&comment_info,10,exception);
         image->rows=(size_t) PNMInteger(image,&comment_info,10,exception);
-        if ((format == 'f') || (format == 'F'))
+        if ((format == 'f') || (format == 'F') || (format == 'h') ||
+            (format == 'H'))
           {
             char
-              scale[MagickPathExtent];
+              scale[32];
 
-            if (ReadBlobString(image,scale) != (char *) NULL)
+            if (PNMString(image,scale,sizeof(scale)) != (char *) NULL)
               quantum_scale=StringToDouble(scale,(char **) NULL);
           }
         else
@@ -1269,17 +1298,89 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Convert PFM raster image to pixel packets.
         */
-        if (format == 'f')
-          (void) SetImageColorspace(image,GRAYColorspace,exception);
-        quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
+        if (format != 'f')
+          quantum_type=image->alpha_trait != UndefinedPixelTrait ? RGBAQuantum :
+            RGBQuantum;
+        else
+          {
+            (void) SetImageColorspace(image,GRAYColorspace,exception);
+            quantum_type=GrayQuantum;
+          }
         image->endian=quantum_scale < 0.0 ? LSBEndian : MSBEndian;
         image->depth=32;
         quantum_info=AcquireQuantumInfo(image_info,image);
         if (quantum_info == (QuantumInfo *) NULL)
           ThrowPNMException(ResourceLimitError,"MemoryAllocationFailed");
-        status=SetQuantumDepth(image,quantum_info,32);
+        status=SetQuantumFormat(image,quantum_info,FloatingPointQuantumFormat);
         if (status == MagickFalse)
           ThrowPNMException(ResourceLimitError,"MemoryAllocationFailed");
+        SetQuantumScale(quantum_info,(double) QuantumRange*fabs(quantum_scale));
+        extent=GetQuantumExtent(image,quantum_info,quantum_type);
+        pixels=GetQuantumPixels(quantum_info);
+        for (y=0; y < (ssize_t) image->rows; y++)
+        {
+          MagickBooleanType
+            sync;
+
+          register Quantum
+            *magick_restrict q;
+
+          ssize_t
+            offset;
+
+          size_t
+            length;
+
+          stream=ReadBlobStream(image,extent,pixels,&count);
+          if (count != (ssize_t) extent)
+            break;
+          if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+              (image->previous == (Image *) NULL))
+            {
+              MagickBooleanType
+                proceed;
+
+              proceed=SetImageProgress(image,LoadImageTag,(MagickOffsetType)
+                row,image->rows);
+              if (proceed == MagickFalse)
+                break;
+            }
+          offset=row++;
+          q=QueueAuthenticPixels(image,0,(ssize_t) (image->rows-offset-1),
+            image->columns,1,exception);
+          if (q == (Quantum *) NULL)
+            break;
+          length=ImportQuantumPixels(image,(CacheView *) NULL,quantum_info,
+            quantum_type,(unsigned char *) stream,exception);
+          if (length != extent)
+            break;
+          sync=SyncAuthenticPixels(image,exception);
+          if (sync == MagickFalse)
+            break;
+        }
+        quantum_info=DestroyQuantumInfo(quantum_info);
+        SetQuantumImageType(image,quantum_type);
+        break;
+      }
+      case 'H':
+      case 'h':
+      {
+        /*
+          Convert PFM raster image to pixel packets.
+        */
+        if (format != 'h')
+          quantum_type=image->alpha_trait != UndefinedPixelTrait ? RGBAQuantum :
+            RGBQuantum;
+        else
+          {
+            (void) SetImageColorspace(image,GRAYColorspace,exception);
+            quantum_type=GrayQuantum;
+          }
+        image->endian=quantum_scale < 0.0 ? LSBEndian : MSBEndian;
+        image->depth=16;
+        quantum_info=AcquireQuantumInfo(image_info,image);
+        if (quantum_info == (QuantumInfo *) NULL)
+          ThrowPNMException(ResourceLimitError,"MemoryAllocationFailed");
         status=SetQuantumFormat(image,quantum_info,FloatingPointQuantumFormat);
         if (status == MagickFalse)
           ThrowPNMException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1419,7 +1520,7 @@ ModuleExport size_t RegisterPNMImage(void)
   entry=AcquireMagickInfo("PNM","PAM","Common 2-dimensional bitmap format");
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
-  entry->mime_type=ConstantString("image/x-portable-pixmap");
+  entry->mime_type=ConstantString("image/x-portable-anymap");
   entry->flags|=CoderDecoderSeekableStreamFlag;
   (void) RegisterMagickInfo(entry);
   entry=AcquireMagickInfo("PNM","PBM",
@@ -1441,6 +1542,12 @@ ModuleExport size_t RegisterPNMImage(void)
   entry->mime_type=ConstantString("image/x-portable-greymap");
   entry->flags|=CoderDecoderSeekableStreamFlag;
   (void) RegisterMagickInfo(entry);
+  entry=AcquireMagickInfo("PNM","PHM","Portable half float format");
+  entry->decoder=(DecodeImageHandler *) ReadPNMImage;
+  entry->encoder=(EncodeImageHandler *) WritePNMImage;
+  entry->flags|=CoderEndianSupportFlag;
+  entry->flags|=CoderDecoderSeekableStreamFlag;
+  (void) RegisterMagickInfo(entry);
   entry=AcquireMagickInfo("PNM","PNM","Portable anymap");
   entry->decoder=(DecodeImageHandler *) ReadPNMImage;
   entry->encoder=(EncodeImageHandler *) WritePNMImage;
@@ -1614,6 +1721,15 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image,
           format='2';
         break;
       }
+      case 'H':
+      case 'h':
+      {
+        format='H';
+        if ((image_info->type != TrueColorType) &&
+            (SetImageGray(image,exception) != MagickFalse))
+          format='h';
+        break;
+      }
       case 'N':
       case 'n':
       {
@@ -2471,6 +2587,47 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image,
         quantum_info=DestroyQuantumInfo(quantum_info);
         break;
       }
+      case 'H':
+      case 'h':
+      {
+        register unsigned char
+          *pixels;
+
+        (void) WriteBlobString(image,image->endian == LSBEndian ? "-1.0\n" :
+          "1.0\n");
+        image->depth=16;
+        quantum_type=format == 'h' ? GrayQuantum : RGBQuantum;
+        quantum_info=AcquireQuantumInfo(image_info,image);
+        if (quantum_info == (QuantumInfo *) NULL)
+          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+        status=SetQuantumFormat(image,quantum_info,FloatingPointQuantumFormat);
+        if (status == MagickFalse)
+          ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+        pixels=GetQuantumPixels(quantum_info);
+        for (y=(ssize_t) image->rows-1; y >= 0; y--)
+        {
+          register const Quantum
+            *magick_restrict p;
+
+          p=GetVirtualPixels(image,0,y,image->columns,1,exception);
+          if (p == (const Quantum *) NULL)
+            break;
+          extent=ExportQuantumPixels(image,(CacheView *) NULL,quantum_info,
+            quantum_type,pixels,exception);
+          (void) WriteBlob(image,extent,pixels);
+          if (image->previous == (Image *) NULL)
+            {
+              status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
+                image->rows);
+              if (status == MagickFalse)
+                break;
+            }
+        }
+        quantum_info=DestroyQuantumInfo(quantum_info);
+        break;
+      }
+      default:
+        break;
     }
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
