@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -166,12 +166,11 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   size_t
     base,
     flag,
-    offset,
-    real,
     skip;
 
   ssize_t
     count,
+    offset,
     y;
 
   TGAInfo
@@ -239,9 +238,13 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   image->columns=tga_info.width;
   image->rows=tga_info.height;
-  alpha_bits=(tga_info.attributes & 0x0FU);
-  image->alpha_trait=(alpha_bits > 0) || (tga_info.bits_per_pixel == 32) ||
-    (tga_info.colormap_size == 32) ?  BlendPixelTrait : UndefinedPixelTrait;
+  if ((tga_info.image_type != TGAMonochrome) &&
+      (tga_info.image_type != TGARLEMonochrome))
+    {
+      alpha_bits=(tga_info.attributes & 0x0FU);
+      image->alpha_trait=(alpha_bits > 0) || (tga_info.bits_per_pixel == 32) ||
+        (tga_info.colormap_size == 32) ?  BlendPixelTrait : UndefinedPixelTrait;
+    }
   if ((tga_info.image_type != TGAColormap) &&
       (tga_info.image_type != TGARLEColormap))
     image->depth=(size_t) ((tga_info.bits_per_pixel <= 8) ? 8 :
@@ -250,10 +253,14 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->depth=(size_t) ((tga_info.colormap_size <= 8) ? 8 :
       (tga_info.colormap_size <= 16) ? 5 : 8);
   if ((tga_info.image_type == TGAColormap) ||
-      (tga_info.image_type == TGAMonochrome) ||
-      (tga_info.image_type == TGARLEColormap) ||
-      (tga_info.image_type == TGARLEMonochrome))
+      (tga_info.image_type == TGARLEColormap))
     image->storage_class=PseudoClass;
+  if ((tga_info.image_type == TGAMonochrome) ||
+      (tga_info.image_type == TGARLEMonochrome))
+    {
+      image->type=GrayscaleType;
+      image->colorspace=GRAYColorspace;
+    }
   image->compression=NoCompression;
   if ((tga_info.image_type == TGARLEColormap) ||
       (tga_info.image_type == TGARLEMonochrome) ||
@@ -303,19 +310,20 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       comment=DestroyString(comment);
     }
-  if (tga_info.attributes & (1UL << 4))
+  image->orientation=BottomLeftOrientation;
+  if ((tga_info.attributes & (1UL << 4)) == 0)
     {
-      if (tga_info.attributes & (1UL << 5))
-        image->orientation=TopRightOrientation;
+      if ((tga_info.attributes & (1UL << 5)) == 0)
+        image->orientation=BottomLeftOrientation;
       else
-        image->orientation=BottomRightOrientation;
+        image->orientation=TopLeftOrientation;
     }
   else
     {
-      if (tga_info.attributes & (1UL << 5))
-        image->orientation=TopLeftOrientation;
+      if ((tga_info.attributes & (1UL << 5)) == 0)
+        image->orientation=BottomRightOrientation;
       else
-        image->orientation=BottomLeftOrientation;
+        image->orientation=TopRightOrientation;
     }
   if (image_info->ping != MagickFalse)
     {
@@ -411,16 +419,12 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
   base=0;
   flag=0;
   skip=MagickFalse;
-  real=0;
   index=0;
   runlength=0;
   offset=0;
   for (y=0; y < (ssize_t) image->rows; y++)
   {
-    real=offset;
-    if (((unsigned char) (tga_info.attributes & 0x20) >> 5) == 0)
-      real=image->rows-real-1;
-    q=QueueAuthenticPixels(image,0,(ssize_t) real,image->columns,1,exception);
+    q=QueueAuthenticPixels(image,0,offset,image->columns,1,exception);
     if (q == (Quantum *) NULL)
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
@@ -535,16 +539,11 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         SetPixelAlpha(image,ClampToQuantum(pixel.alpha),q);
       q+=GetPixelChannels(image);
     }
-    /*
-      if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 4)
-        offset+=4;
-      else
-    */
-      if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 2)
-        offset+=2;
-      else
-        offset++;
-    if (offset >= image->rows)
+    if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 2)
+      offset+=2;
+    else
+      offset++;
+    if (offset >= (ssize_t) image->rows)
       {
         base++;
         offset=base;
@@ -751,7 +750,9 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image,
     channels;
 
   ssize_t
+    base,
     count,
+    offset,
     y;
 
   TGAInfo
@@ -843,6 +844,7 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image,
       (image->orientation == TopRightOrientation))
     tga_info.attributes|=(1UL << 4);
   if ((image->orientation == TopLeftOrientation) ||
+      (image->orientation == UndefinedOrientation) ||
       (image->orientation == TopRightOrientation))
     tga_info.attributes|=(1UL << 5);
   if ((image->columns > 65535) || (image->rows > 65535))
@@ -906,10 +908,12 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image,
   /*
     Convert MIFF to TGA raster pixels.
   */
+  base=0;
+  offset=0;
   channels=GetPixelChannels(image);
-  for (y=(ssize_t) (image->rows-1); y >= 0; y--)
+  for (y=0; y < (ssize_t) image->rows; y++)
   {
-    p=GetVirtualPixels(image,0,y,image->columns,1,exception);
+    p=GetVirtualPixels(image,0,offset,image->columns,1,exception);
     if (p == (const Quantum *) NULL)
       break;
     if (compression == RLECompression)
@@ -928,26 +932,27 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image,
                     GetPixelIndex(image,p+((i-1)*channels)))
                   break;
               }
-            else if (tga_info.image_type == TGARLEMonochrome)
-              {
-                if (GetPixelLuma(image,p+(i*channels)) !=
-                    GetPixelLuma(image,p+((i-1)*channels)))
-                  break;
-              }
             else
-              {
-                if ((GetPixelBlue(image,p+(i*channels)) !=
-                     GetPixelBlue(image,p+((i-1)*channels))) ||
-                    (GetPixelGreen(image,p+(i*channels)) !=
-                     GetPixelGreen(image,p+((i-1)*channels))) ||
-                    (GetPixelRed(image,p+(i*channels)) !=
-                     GetPixelRed(image,p+((i-1)*channels))))
-                  break;
-                if ((image->alpha_trait != UndefinedPixelTrait) &&
-                    (GetPixelAlpha(image,p+(i*channels)) !=
-                     GetPixelAlpha(image,p+(i-1)*channels)))
-                  break;
-              }
+              if (tga_info.image_type == TGARLEMonochrome)
+                {
+                  if (GetPixelLuma(image,p+(i*channels)) !=
+                      GetPixelLuma(image,p+((i-1)*channels)))
+                    break;
+                }
+              else
+                {
+                  if ((GetPixelBlue(image,p+(i*channels)) !=
+                       GetPixelBlue(image,p+((i-1)*channels))) ||
+                      (GetPixelGreen(image,p+(i*channels)) !=
+                       GetPixelGreen(image,p+((i-1)*channels))) ||
+                      (GetPixelRed(image,p+(i*channels)) !=
+                       GetPixelRed(image,p+((i-1)*channels))))
+                    break;
+                  if ((image->alpha_trait != UndefinedPixelTrait) &&
+                      (GetPixelAlpha(image,p+(i*channels)) !=
+                       GetPixelAlpha(image,p+(i-1)*channels)))
+                    break;
+                }
             i++;
           }
           if (i < 3)
@@ -980,13 +985,20 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image,
         }
       }
     else
+      for (x=0; x < (ssize_t) image->columns; x++)
       {
-        for (x=0; x < (ssize_t) image->columns; x++)
-          {
-            WriteTGAPixel(image,tga_info.image_type,p,range,midpoint);
-            p+=channels;
-          }
+        WriteTGAPixel(image,tga_info.image_type,p,range,midpoint);
+        p+=channels;
       }
+     if (((unsigned char) (tga_info.attributes & 0xc0) >> 6) == 2)
+       offset+=2;
+     else
+       offset++;
+      if (offset >= (ssize_t) image->rows)
+        {
+          base++;
+          offset=base;
+        }
     if (image->previous == (Image *) NULL)
       {
         status=SetImageProgress(image,SaveImageTag,(MagickOffsetType) y,
