@@ -307,8 +307,8 @@ static int ReadSingleWEBPImage(Image *image,const uint8_t *stream,
       break;
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if ((x >= x_offset && x < x_offset + image_width) &&
-          (y >= y_offset && y < y_offset + image_height))
+      if ((x >= x_offset && x < (ssize_t) (x_offset+image_width)) &&
+          (y >= y_offset && y < (ssize_t) (y_offset+image_height)))
         {
           SetPixelRed(image,ScaleCharToQuantum(*p++),q);
           SetPixelGreen(image,ScaleCharToQuantum(*p++),q);
@@ -425,6 +425,22 @@ static int ReadAnimatedWEBPImage(const ImageInfo *image_info,Image *image,
   canvas_height=image->rows;
   data.bytes=stream;
   data.size=length;
+  {
+    WebPMux
+      *mux;
+
+    WebPMuxAnimParams
+      params;
+
+    WebPMuxError
+      status;
+
+    mux=WebPMuxCreate(&data,0);
+    status=WebPMuxGetAnimationParams(mux,&params);
+    if (status >= 0)
+      image->iterations=params.loop_count;
+    WebPMuxDelete(mux);
+  }
   demux=WebPDemux(&data);
   if (WebPDemuxGetFrame(demux,1,&iter))
     {
